/**
 *
 * FreeBridge is a Java-Based application to play bridge on your computer.
 * Copyright (C) Axelle and Ludovic Apvrille
 * 
 * This program is free software; you can redistribute it and/or modify it under the 
 * terms of the GNU General Public License as published by the Free Software Foundation; 
 * either version 2 of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE. See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with this 
 * program; if not, write to the 
 *	 Free Software Foundation, Inc., 59 Temple Place, 
 *	 Suite 330, Boston, MA 02111-1307 USA
 *
 */
package freebridge.core;

import freebridge.console.ConsolePlayer;
import org.apache.log4j.Category;

/**
 * A match is 4 games with the same players, using different vulnerabilities at
 * each turn.
 * 
 * @author Axelle Apvrille
 * @version 0.1
 */

public class Match {
    static Category cat = Category.getInstance(Match.class.getName());
    
    protected Player north,east,south,west;
    protected Vulnerability vuln;
    protected Orientation dealer;
    
    /**
     * A match is a sequencee of 4 games with the same players.
     * The first dealer of the match will always be north. And at first, nobody
     * is vulnerable.
     */
    public Match(){
	cat.debug("> Match()");
	vuln = new Vulnerability();
	try {
	    dealer = new Orientation(Orientation.NORTH);
	}
	catch(BadTypeException exp){
	    cat.fatal("Shouldn't occur:"+exp);
	    System.exit(-1);
	}
	cat.debug("< Match()");
    }

    public void setNorth(Player n){
	north = n;
    }

    public void setEast(Player n){
	cat.debug("> setEast(): n="+n);
	try {
	    east = n;
	    east.setOrientation(new Orientation(Orientation.EAST));
	}
	catch(BadTypeException exp){
	    // Shouldn't occur unless there's a bug.
	    cat.fatal("Unexpected exception: "+exp);
	    System.exit(0);
	}	
	cat.debug("< setEast()");
    }
    
    public void setSouth(Player n){
	cat.debug("> setSouth(): n="+n);
	try {
	    south = n;
	    south.setOrientation(new Orientation(Orientation.SOUTH));
	}
	catch(BadTypeException exp){
	    // Shouldn't occur unless there's a bug.
	    cat.fatal("Unexpected exception: "+exp);
	    System.exit(0);
	}	
	cat.debug("< setSouth()");
    }
    
    public void setWest(Player n){
	cat.debug("> setWest(): n="+n);
	try {
	    west = n;
	    west.setOrientation(new Orientation(Orientation.WEST));
	}
	catch(BadTypeException exp){
	    // Shouldn't occur unless there's a bug.
	    cat.fatal("Unexpected exception: "+exp);
	    System.exit(0);
	}	
	cat.debug("< setWest()");
    }

    public Player getNorth() { return north; }
    public Player getEast() { return east; }
    public Player getSouth() { return south; }
    public Player getWest() { return west; }

    public Vulnerability getVulnerability() { return vuln; }
    public Orientation getDealer() { return dealer; }

    public void nextGame() {
	cat.debug("> nextGame()");

	try {
	    vuln.setVulnerability(vuln.next());
	    dealer = dealer.next();
	}
	catch(BadTypeException exp){
	    cat.fatal("Unexpected exception caught: "+exp);
	    System.exit(-1);
	}
	cat.debug("< nextGame(): vuln="+vuln+" dealer="+dealer);
    }
}
