package freebridge.test;

import org.apache.log4j.Category;
import junit.framework.*;
import freebridge.core.*;
import freebridge.console.ConsolePlayer;

public class GameTest extends TestCase {
    static Category cat = Category.getInstance(GameTest.class.getName());
    ConsolePlayer n,e,s,w;
    

    public static Test suite(){
	return new TestSuite(GameTest.class);
    }

    protected void setUp(){
	cat.debug("> setUp()");
	n = new ConsolePlayer("Croc' Mister");
	e = new ConsolePlayer("Picus");
	s = new ConsolePlayer("Croc' Miss");
	w = new ConsolePlayer("Hareng Glouton");
	cat.debug("< setUp()");
    }

    public void testGetSet(){
	cat.debug("Testing get/set");
	Game g = new Game();
	g.getCurrentMatch().setNorth(n);
	g.getCurrentMatch().setEast(e);
	g.getCurrentMatch().setSouth(s);
	g.getCurrentMatch().setWest(w);

	Assert.assertEquals("Picus",g.getCurrentMatch().getEast().getName());
	Assert.assertEquals(Vulnerability.NOBODY,g.getCurrentMatch().getVulnerability().getVulnerability());
	Assert.assertEquals(Orientation.NORTH,g.getCurrentMatch().getDealer().getOrientation());
	Assert.assertEquals(null,g.getLeader());
	
	try {
	    cat.debug("Let's set the leader");
	    g.setLeader(new Orientation(Orientation.SOUTH));
	    Assert.assertEquals(Orientation.SOUTH,g.getLeader().getOrientation());
	}
	catch(Exception exp){
	    cat.error("Unexpected exception: "+exp.toString());
	    fail("Unexpected exception: "+exp.toString());
	}
    }

    public void testConstruct(){
	cat.debug("Constructing a game from a match");
	Match m = new Match();
	m.setNorth(n);
	m.setEast(e);
	m.setSouth(s);
	m.setWest(w);
	Game g = new Game(m);
	
	try {
	    g.setLeader(new Orientation(Orientation.EAST));
	    Assert.assertEquals(Orientation.EAST,g.getLeader().getOrientation());
	}
	catch(Exception exp){
	    cat.error("Unexpected exception: "+exp.toString());
	    fail("Unexpected exception: "+exp.toString());
	}
    }

    public void testGetDealer(){
	cat.debug("> testGetDealer()");
	Game g = new Game();

	Assert.assertEquals(Orientation.NORTH,g.getCurrentMatch().getDealer().getOrientation());

	Match m = new Match();
	m.setNorth(n);
	m.setEast(e);
	m.setSouth(s);
	m.setWest(w);
	Game g1 = new Game(m);

	Assert.assertEquals(Orientation.NORTH,g1.getCurrentMatch().getDealer().getOrientation());
	

	cat.debug("< testGetDealer()");
    }

    public void testDoDeal(){
	cat.debug("> testDoDeal()");
	Match m = new Match();
	m.setNorth(n);
	m.setEast(e);
	m.setSouth(s);
	m.setWest(w);
	Game g = new Game(m);

	cat.info("Dealing the cards...");
	g.doDeal();
	cat.debug("< testDoDeal()");
    }
}
