package freebridge.test;

import org.apache.log4j.Category;
import junit.framework.*;
import freebridge.core.*;

public class TrickTest extends TestCase {
    static Category cat = Category.getInstance(TrickTest.class.getName());

    public static Test suite(){
	return new TestSuite(TrickTest.class);
    }

    public void testGetSet(){
	cat.debug("Sets the orientation of a lift, and tests its initial state.");
	try {
	    Trick l = new Trick();
	    Orientation o = new Orientation(Orientation.SOUTH);
	    l.setStart(o);
	    Assert.assertEquals(o,l.getStart());
	    Assert.assertTrue(l.getCards().isEmpty());
	}
	catch(Exception exp){
	    cat.error("Unexpected exception: "+exp);
	    fail("Unexpected exception: "+exp);
	}
    }

    public void testAdd(){
	cat.debug("Testint addCard and wins()");
	try {
	    cat.debug("The current bid is 3Hearts");
	    Trick l = new Trick();
	    Bid b = new Bid();
	    b.setSuit(Card.HEART);
	    b.setValue(3);

	    cat.debug("We build a hand");
	    Hand h = new Hand();
	    Card c1 = new Card(2,Card.HEART);
	    Card c2 = new Card(3,Card.SPADES);
	    Card c3 = new Card(10,Card.SPADES);

	    h.addCard(c1);
	    h.addCard(c2);
	    h.addCard(c3);
	    
	    cat.debug("EAST is the first to play");
	    Orientation start = new Orientation(Orientation.EAST);
	    l.setStart(start);

	    cat.debug("East plays 3 Spades: "+c2);
	    l.addCard(b,c2,h); // EAST

	    cat.debug("South plays 10 spades: "+c3);
	    l.addCard(b,c3,h); // it would actually be stupid to add cards of the same hand !

	    cat.debug("West plays trump: 2 heart: "+c1);
	    l.addCard(b,c1,h); // WEST
	    
	    cat.info("The current lift looks like: "+l.toString());

	    cat.debug("West currently wins the lift...");
	    Orientation o = l.wins(b);
	    Assert.assertEquals(Orientation.WEST,o.getOrientation());
	}
	catch(Exception exp){
	    cat.error("Unexpected exception: "+exp);
	    fail("Unexpected exception: "+exp);
	}
    }
}
